Added parameter 'clear_bound_vars', so we could reset the statement without clearing bound variables, so and current row is reset to the beginning.

It is used to support the Andorid' sqlite cursor feature which could move the cursor around the result set.

BUG=
TEST=Added a new test.
TBR=agl,akalin,michaeln

Review URL: http://codereview.chromium.org/10171014

git-svn-id: svn://svn.chromium.org/chrome/trunk/src@133985 0039d316-1c4b-4281-b951-d872f2087c98
diff --git a/sql/statement.h b/sql/statement.h
index 92d1ef2f..269684f 100644
--- a/sql/statement.h
+++ b/sql/statement.h
@@ -87,9 +87,9 @@
   //   return s.Succeeded();
   bool Step();
 
-  // Resets the statement to its initial condition. This includes clearing all
-  // the bound variables and any current result row.
-  void Reset();
+  // Resets the statement to its initial condition. This includes any current
+  // result row, and also the bound variables if the |clear_bound_vars| is true.
+  void Reset(bool clear_bound_vars);
 
   // Returns true if the last executed thing in this statement succeeded. If
   // there was no last executed thing or the statement is invalid, this will